@@ -14,7 +14,7 @@
 # limitations under the License.
 
 
-# 该帐号已被注册。
+# 该账号已被注册。
 FAILEDOPERATION_ACCOUNTALREADYREGISTER = 'FailedOperation.AccountAlreadyRegister'
 
 # 用户未实名。
@@ -104,7 +104,7 @@ FAILEDOPERATION_MEMBERNAMEUSED = 'FailedOperation.MemberNameUsed'
 # 成员授权策略名已存在。
 FAILEDOPERATION_MEMBERPOLICYNAMEEXIST = 'FailedOperation.MemberPolicyNameExist'
 
-# 成员正在共享资源。
+# 成员正在共享资源，不允许退出组织。
 FAILEDOPERATION_MEMBERSHARERESOURCE = 'FailedOperation.MemberShareResource'
 
 # 企业组织单元成员不为空。
@@ -116,7 +116,7 @@ FAILEDOPERATION_OPERATEBILLINGPERMISSIONERR = 'FailedOperation.OperateBillingPer
 # 操作策略失败。
 FAILEDOPERATION_OPERATEPOLICY = 'FailedOperation.OperatePolicy'
 
-# 成员是主体管理账号不允许删除。
+# 成员是主体管理账号，不允许退出组织。
 FAILEDOPERATION_ORGANIZATIONAUTHMANAGENOTALLOWDELETE = 'FailedOperation.OrganizationAuthManageNotAllowDelete'
 
 # 企业组织已经存在。
@@ -158,6 +158,9 @@ FAILEDOPERATION_ORGANIZATIONPOLICYILLEGAL = 'FailedOperation.OrganizationPolicyI
 # 集团策略不是禁用状态。
 FAILEDOPERATION_ORGANIZATIONPOLICYISNOTDISABLED = 'FailedOperation.OrganizationPolicyIsNotDisabled'
 
+# 调用经销系统报错。
+FAILEDOPERATION_PARTNERMANAGEMENTERR = 'FailedOperation.PartnerManagementErr'
+
 # 代付者不合法。
 FAILEDOPERATION_PAYUINILLEGAL = 'FailedOperation.PayUinIllegal'
 
@@ -248,6 +251,9 @@ RESOURCENOTFOUND_MEMBERNOTEXIST = 'ResourceNotFound.MemberNotExist'
 # 组织成员策略不存在。
 RESOURCENOTFOUND_MEMBERPOLICYNOTEXIST = 'ResourceNotFound.MemberPolicyNotExist'
 
+# 认证主体不存在。
+RESOURCENOTFOUND_ORGANIZATIONAUTHRELATIONNOTEXIST = 'ResourceNotFound.OrganizationAuthRelationNotExist'
+
 # 组织身份不存在。
 RESOURCENOTFOUND_ORGANIZATIONIDENTITYNOTEXIST = 'ResourceNotFound.OrganizationIdentityNotExist'
 
@@ -272,6 +278,9 @@ RESOURCENOTFOUND_USERNOTEXIST = 'ResourceNotFound.UserNotExist'
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# 代付者财务状态异常，不支持代付费。
+UNSUPPORTEDOPERATION_ABNORMALFINANCIALSTATUSOFADMIN = 'UnsupportedOperation.AbnormalFinancialStatusOfAdmin'
+
 # 不允许添加代付关系。
 UNSUPPORTEDOPERATION_ADDDELEGATEPAYERNOTALLOW = 'UnsupportedOperation.AddDelegatePayerNotAllow'
 
@@ -281,12 +290,15 @@ UNSUPPORTEDOPERATION_ADDDISCOUNTINHERITNOTALLOW = 'UnsupportedOperation.AddDisco
 # 创建的成员不允许创建组织。
 UNSUPPORTEDOPERATION_CREATEMEMBERNOTALLOWCREATEORGANIZATION = 'UnsupportedOperation.CreateMemberNotAllowCreateOrganization'
 
-# 创建的成员不允许删除。
+# 创建的成员不允许移除组织。
 UNSUPPORTEDOPERATION_CREATEMEMBERNOTALLOWDELETE = 'UnsupportedOperation.CreateMemberNotAllowDelete'
 
 # 创建的成员不允许退出。
 UNSUPPORTEDOPERATION_CREATEMEMBERNOTALLOWQUIT = 'UnsupportedOperation.CreateMemberNotAllowQuit'
 
+# 成员删除许可未开启。
+UNSUPPORTEDOPERATION_DELETEACCOUNTDISABLED = 'UnsupportedOperation.DeleteAccountDisabled'
+
 # 不允许删除代付关系。
 UNSUPPORTEDOPERATION_DELETEDELEGATEPAYERNOTALLOW = 'UnsupportedOperation.DeleteDelegatePayerNotAllow'
 
@@ -299,12 +311,18 @@ UNSUPPORTEDOPERATION_EXISTEDCLIENT = 'UnsupportedOperation.ExistedClient'
 # 用户类型不一致。
 UNSUPPORTEDOPERATION_INCONSISTENTUSERTYPES = 'UnsupportedOperation.InconsistentUserTypes'
 
+# 邀请的成员不允许删除。
+UNSUPPORTEDOPERATION_INVITEACCOUNTNOTALLOWDELETE = 'UnsupportedOperation.InviteAccountNotAllowDelete'
+
 # 调用经管系统报错。
 UNSUPPORTEDOPERATION_MANAGEMENTSYSTEMERROR = 'UnsupportedOperation.ManagementSystemError'
 
 # 成员账户欠费。
 UNSUPPORTEDOPERATION_MEMBERACCOUNTARREARS = 'UnsupportedOperation.MemberAccountArrears'
 
+# 成员账号存在资源，不允许删除。
+UNSUPPORTEDOPERATION_MEMBERACCOUNTEXISTRESOURCE = 'UnsupportedOperation.MemberAccountExistResource'
+
 # 成员存在优惠继承。
 UNSUPPORTEDOPERATION_MEMBERDISCOUNTINHERITEXISTED = 'UnsupportedOperation.MemberDiscountInheritExisted'
 
@@ -314,7 +332,7 @@ UNSUPPORTEDOPERATION_MEMBEREXISTACCOUNTLEVELDISCOUNTINHERIT = 'UnsupportedOperat
 # 成员设置了操作审批,不允许删除。
 UNSUPPORTEDOPERATION_MEMBEREXISTOPERATEPROCESSNOTALLOWDELETE = 'UnsupportedOperation.MemberExistOperateProcessNotAllowDelete'
 
-# 组织成员被委派集团服务，不允许退出。
+# 成员是集团服务委派管理员，不允许退出组织。
 UNSUPPORTEDOPERATION_MEMBEREXISTSERVICENOTALLOWDELETE = 'UnsupportedOperation.MemberExistServiceNotAllowDelete'
 
 # 账号是代理商或代客。
@@ -337,3 +355,6 @@ UNSUPPORTEDOPERATION_PAYERARREARSANDNOCREDITACCOUNT = 'UnsupportedOperation.Paye
 
 # 代付者存在账户级优惠。
 UNSUPPORTEDOPERATION_PAYEREXISTACCOUNTLEVELDISCOUNTINHERIT = 'UnsupportedOperation.PayerExistAccountLevelDiscountInherit'
+
+# 存在二级经销商子客，不支持代付费。
+UNSUPPORTEDOPERATION_SECONDARYDISTRIBUTORSUBCLIENTEXISTED = 'UnsupportedOperation.SecondaryDistributorSubClientExisted'
