@@ -38,6 +38,9 @@ FAILEDOPERATION_FREQUENCYLIMIT = 'FailedOperation.FrequencyLimit'
 # 拒信率过高，被临时block。
 FAILEDOPERATION_HIGHREJECTIONRATE = 'FailedOperation.HighRejectionRate'
 
+# 邮件包含不合规链接
+FAILEDOPERATION_ILLEGALURL = 'FailedOperation.IllegalURL'
+
 # 邮箱地址错误。
 FAILEDOPERATION_INCORRECTEMAIL = 'FailedOperation.IncorrectEmail'
 
@@ -50,7 +53,7 @@ FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 # 套餐包额度不足。
 FAILEDOPERATION_INSUFFICIENTQUOTA = 'FailedOperation.InsufficientQuota'
 
-# 不支持的附件名称，请检查附件名称是否含有特殊字符，详情请参考附录附件说明。
+# 不支持的附件名称，请检查附件名称是否含有特殊字符，详情请参考[附录附件说明](https://cloud.tencent.com/document/product/1288/51951)。
 FAILEDOPERATION_INVALIDATTACHNAME = 'FailedOperation.InvalidAttachName'
 
 # 超过查询限制，Limit最大支持100。
@@ -89,7 +92,7 @@ FAILEDOPERATION_SERVICENOTAVAILABLE = 'FailedOperation.ServiceNotAvailable'
 # 模板内容太大，请减少模板内容。
 FAILEDOPERATION_TEMPLATECONTENTTOOLARGE = 'FailedOperation.TemplateContentToolarge'
 
-# 因触发了某些规则导致临时Block。
+# 因触发了对应的收件服务商限制，邮件推送平台会对该服务商发信暂停10分钟，10分钟后自动解除。
 FAILEDOPERATION_TEMPORARYBLOCKED = 'FailedOperation.TemporaryBlocked'
 
 # 附件数量太多，单封邮件最多支持10个附件。
