@@ -41,24 +41,78 @@ FAILEDOPERATION_CANNOTBEDELETEDWITHINHOUR = 'FailedOperation.CannotBeDeletedWith
 # 获取订单信息失败，请稍后重试。
 FAILEDOPERATION_CANNOTGETORDER = 'FailedOperation.CannotGetOrder'
 
+# 温馨提示：上传的证书内容不符合CA证书的标准格式，请您核对证书类型是否有误
+FAILEDOPERATION_CERTIFICATECAERROR = 'FailedOperation.CertificateCaError'
+
+# 记录状态必须完结才可以执行该操作。
+FAILEDOPERATION_CERTIFICATEDEPLOYDETAILROLLBACKSTATUSINVALID = 'FailedOperation.CertificateDeployDetailRollbackStatusInvalid'
+
+# 证书部署有正在进行中的任务，请部署完成后再重试。
+FAILEDOPERATION_CERTIFICATEDEPLOYHASPENDINGRECORD = 'FailedOperation.CertificateDeployHasPendingRecord'
+
+# 已选择的云资源无实例，无法更新，请重新核对后重试。
+FAILEDOPERATION_CERTIFICATEDEPLOYINSTANCEEMPTY = 'FailedOperation.CertificateDeployInstanceEmpty'
+
+# 证书部署记录不存在。
+FAILEDOPERATION_CERTIFICATEDEPLOYNOTEXIST = 'FailedOperation.CertificateDeployNotExist'
+
+# 记录状态必须失败才可以执行该操作。
+FAILEDOPERATION_CERTIFICATEDEPLOYRETRYSTATUSINVALID = 'FailedOperation.CertificateDeployRetryStatusInvalid'
+
+# 必须有部署成功的记录才可以回滚。
+FAILEDOPERATION_CERTIFICATEDEPLOYROLLBACKSTATUSINVALID = 'FailedOperation.CertificateDeployRollbackStatusInvalid'
+
+# 证书内容疑似国密证书，与所选证书标准不符，请您核对选择的证书标准和证书内容是否有误
+FAILEDOPERATION_CERTIFICATEENCRYPTINVALID = 'FailedOperation.CertificateEncryptInvalid'
+
 # 证书已存在。
 FAILEDOPERATION_CERTIFICATEEXISTS = 'FailedOperation.CertificateExists'
 
 # 已替换证书，无法进行托管。
 FAILEDOPERATION_CERTIFICATEHASRENEWED = 'FailedOperation.CertificateHasRenewed'
 
+# 当前证书不允许使用一键更新的功能。
+FAILEDOPERATION_CERTIFICATEHOSTDEPLOYCANNOTALLOW = 'FailedOperation.CertificateHostDeployCanNotAllow'
+
+# 当前为内部账号，账号涉及实例资源较多，无法使用部署功能，请联系SSL证书特殊处理。
+FAILEDOPERATION_CERTIFICATEHOSTRESOURCEINNERINTERRUPT = 'FailedOperation.CertificateHostResourceInnerInterrupt'
+
+# 当前账号下实例数量过多，无法正常加载，请您切换加载方式。切换后点击“刷新列表”等待一段时间后即可全部加载。
+FAILEDOPERATION_CERTIFICATEHOSTRESOURCEINSTANCEHUGELIMIT = 'FailedOperation.CertificateHostResourceInstanceHugeLimit'
+
+# 云资源类型无效。
+FAILEDOPERATION_CERTIFICATEHOSTRESOURCETYPEINVALID = 'FailedOperation.CertificateHostResourceTypeInvalid'
+
 # 证书资源托管数量超过限制。
 FAILEDOPERATION_CERTIFICATEHOSTINGTYPENUMBERLIMIT = 'FailedOperation.CertificateHostingTypeNumberLimit'
 
 # 证书不符合标准。
 FAILEDOPERATION_CERTIFICATEINVALID = 'FailedOperation.CertificateInvalid'
 
+# 温馨提示：证书内容和私钥不匹配，请您核对（请留意是否有多余的空格）
+FAILEDOPERATION_CERTIFICATEMATCHERROR = 'FailedOperation.CertificateMatchError'
+
 # 证书与私钥不对应。
 FAILEDOPERATION_CERTIFICATEMISMATCH = 'FailedOperation.CertificateMismatch'
 
+# 证书不可用，请检查后再试。
+FAILEDOPERATION_CERTIFICATENOTAVAILABLE = 'FailedOperation.CertificateNotAvailable'
+
+# 证书不可以部署到实例列表下。
+FAILEDOPERATION_CERTIFICATENOTDEPLOYINSTANCE = 'FailedOperation.CertificateNotDeployInstance'
+
 # 证书不存在。
 FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
 
+# 该证书不存在或不可取消。
+FAILEDOPERATION_CERTIFICATENOTFOUNDORCANTCANCEL = 'FailedOperation.CertificateNotFoundOrCantCancel'
+
+# 解析失败，请检查证书是否符合标准，请留意是否有多余的空格
+FAILEDOPERATION_CERTIFICATEPARSEERROR = 'FailedOperation.CertificateParseError'
+
+# 证书状态不允许重新申请。
+FAILEDOPERATION_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'FailedOperation.CertificateStatusNotAllowResubmit'
+
 # 证书确认函文件过大（需小于1.4M）。
 FAILEDOPERATION_CONFIRMLETTERTOOLARGE = 'FailedOperation.ConfirmLetterTooLarge'
 
@@ -128,6 +182,9 @@ FAILEDOPERATION_PACKAGECOUNTLIMIT = 'FailedOperation.PackageCountLimit'
 # 权益包已过期。
 FAILEDOPERATION_PACKAGEEXPIRED = 'FailedOperation.PackageExpired'
 
+# 权益包不存在。
+FAILEDOPERATION_PACKAGENOTFOUND = 'FailedOperation.PackageNotFound'
+
 # 证书吊销失败。
 FAILEDOPERATION_REVOKEFAILED = 'FailedOperation.RevokeFailed'
 
@@ -140,6 +197,9 @@ FAILEDOPERATION_ROLENOTFOUNDAUTHORIZATION = 'FailedOperation.RoleNotFoundAuthori
 # 系统错误。
 FAILEDOPERATION_SYSTEMERROR = 'FailedOperation.SystemError'
 
+# 计费中心错误。
+FAILEDOPERATION_TRADEERROR = 'FailedOperation.TradeError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -155,15 +215,42 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 查询的证书ID不能超过50个。
 INVALIDPARAMETER_CERTIFICATEIDNUMBERLIMIT = 'InvalidParameter.CertificateIdNumberLimit'
 
+# 当前证书状态不允许重新提交申请。
+INVALIDPARAMETER_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'InvalidParameter.CertificateStatusNotAllowResubmit'
+
 # 证书数量超出限制。
 INVALIDPARAMETER_CERTIFICATESNUMBEREXCEEDED = 'InvalidParameter.CertificatesNumberExceeded'
 
 # 包含无效的证书ID。
 INVALIDPARAMETER_CONTAINSINVALIDCERTIFICATEID = 'InvalidParameter.ContainsInvalidCertificateId'
 
+# 域名数量无效。
+INVALIDPARAMETER_DOMAINCOUNTINVALID = 'InvalidParameter.DomainCountInvalid'
+
+# 域名无效，请重新输入。
+INVALIDPARAMETER_DOMAININVALID = 'InvalidParameter.DomainInvalid'
+
+# 没有匹配的私钥。
+INVALIDPARAMETER_MISSMATCHPRIVATEKEY = 'InvalidParameter.MissMatchPrivateKey'
+
 # 权益点ID列表无效。
 INVALIDPARAMETER_PACKAGEIDSINVALID = 'InvalidParameter.PackageIdsInvalid'
 
+# 证书期限无效。
+INVALIDPARAMETER_PERIODINVALID = 'InvalidParameter.PeriodInvalid'
+
+# 产品PID无效。
+INVALIDPARAMETER_PRODUCTPIDINVALID = 'InvalidParameter.ProductPidInvalid'
+
+# 算法无效。
+INVALIDPARAMETER_RENEWALGORITHMINVALID = 'InvalidParameter.RenewAlgorithmInvalid'
+
+# CSR无效。
+INVALIDPARAMETER_RENEWCSRINVALID = 'InvalidParameter.RenewCsrInvalid'
+
+# 生成CSR方式无效。
+INVALIDPARAMETER_RENEWGENCSRMETHODINVALID = 'InvalidParameter.RenewGenCsrMethodInvalid'
+
 # 参数有误。
 INVALIDPARAMETER_WITHDETAILREASON = 'InvalidParameter.WithDetailReason'
 
